OC.L10N.register(
    "photos",
    {
    "Photos" : "사진",
    "Videos" : "동영상",
    "Folders" : "폴더",
    "Favorites" : "즐겨찾기",
    "Shared with you" : "나와 공유됨",
    "Tags" : "태그",
    "Locations" : "위치",
    "Back" : "뒤로",
    "Save" : "저장",
    "View" : "보기",
    "An error occurred" : "오류가 발생함",
    "Favorite" : "즐겨찾기",
    "Remove from favorites" : "즐겨찾기에서 제거",
    "Add" : "추가",
    "Download" : "다운로드",
    "Delete" : "삭제",
    "Settings" : "설정"
},
"nplurals=1; plural=0;");
